@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.11';
+our $VERSION = '2.21';
 
 use Cwd 3;
 use Try::Tiny;
@@ -89,7 +89,16 @@ sub _FindMatchingZoneinfoFile {
     shift;
     my $file_to_match = shift;
 
-    return unless -d $ZoneinfoDir;
+    # For some reason, under at least macOS 10.13 High Sierra,
+    # /usr/share/zoneinfo is a link to a link to a directory. And no, I didn't
+    # stutter. This is fine, and it passes the -d below. But File::Find does
+    # not understand a link to be a directory, so rather than incur the
+    # overhead of telling File::Find::find() to follow symbolic links, we just
+    # resolve it here.
+    my $zone_info_dir = $ZoneinfoDir;
+    $zone_info_dir = readlink $zone_info_dir while -l $zone_info_dir;
+
+    return unless -d $zone_info_dir;
 
     require File::Basename;
     require File::Compare;
@@ -117,7 +126,7 @@ sub _FindMatchingZoneinfoFile {
                         # false positive
                         && File::Basename::basename($_) ne 'posixrules'
                         && File::Compare::compare( $_, $file_to_match ) == 0
-                        ) {
+                    ) {
                         $real_name = $_;
 
                         # File::Find has no mechanism for bailing in the
@@ -127,7 +136,7 @@ sub _FindMatchingZoneinfoFile {
                 },
                 no_chdir => 1,
             },
-            $ZoneinfoDir,
+            $zone_info_dir,
         );
     }
     catch {
@@ -274,7 +283,7 @@ DateTime::TimeZone::Local::Unix - Determine the local system's time zone on Unix
 
 =head1 VERSION
 
-version 2.11
+version 2.21
 
 =head1 SYNOPSIS
 
@@ -334,6 +343,25 @@ If this file exists, it is opened and we look for a line starting like
 
 =back
 
+B<Note:> Some systems such as virtual machine boxes may lack any of these
+files. You can confirm that this is case by running:
+
+    $ ls -l /etc/localtime /etc/timezone /etc/TIMEZONE \
+        /etc/sysconfig/clock /etc/default/init
+
+If this is the case, then when checking for timezone handling you are
+likely to get an exception:
+
+    $ perl -wle 'use DateTime; DateTime->now( time_zone => "local" )'
+    Cannot determine local time zone
+
+In that case, you should consult your system F<man> pages for details on how
+to address that problem. In one such case reported to us, a FreeBSD virtual
+machine had been built without any of these files. The user was able to run
+the FreeBSD F<tzsetup> utility. That installed F</etc/localtime>, after which
+the above timezone diagnostic ran silently, I<i.e.>, without throwing an
+exception.
+
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
@@ -350,7 +378,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dave Rolsky.
+This software is copyright (c) 2018 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
