@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.11';
+our $VERSION = '2.21';
 
 use DateTime::TimeZone::OlsonDB::Rule;
 use DateTime::TimeZone::OlsonDB::Zone;
@@ -243,8 +243,8 @@ sub utc_datetime_for_time_spec {
     $second = 0 unless defined $second;
 
     my $add_day = 0;
-    if ( $hour == 24 ) {
-        $hour    = 0;
+    if ( $hour >= 24 ) {
+        $hour    = $hour - 24;
         $add_day = 1;
     }
 
@@ -300,7 +300,7 @@ DateTime::TimeZone::OlsonDB - An object to represent an Olson time zone database
 
 =head1 VERSION
 
-version 2.11
+version 2.21
 
 =head1 SYNOPSIS
 
@@ -349,7 +349,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dave Rolsky.
+This software is copyright (c) 2018 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
